<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Ідентифікація за обличчям</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Перевірку пройдено</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Перевірку не пройдено. Лишилася лише одна спроба.</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Перевірте ваш ідентифікатор обличчя</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Ідентифікатор обличчя заблоковано. Скористайтеся, будь ласка, паролем</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Перевірити ваш відбиток</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Перевірку пройдено</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Перевірку не пройдено. Лишилася одна спроба.</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Відбиток заблоковано. Будь ласка, скористайтеся паролем.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Будь ласка, повторіть спробу за хвилину</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Ідентифікаціія за райдужкою</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Перевірку пройдено</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Перевірку не пройдено. Лишилася лише одна спроба.</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Перевірте ваш ідентифікатор райдужки</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Ідентифікатор райдужки заблоковано. Скористайтеся, будь ласка, паролем</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Перевірку пройдено</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Перевірку не пройдено. Лишилася одна спроба.</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Помилковий пароль</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Будь ласка, повторіть спробу за хвилину</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Скинути пароль</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Забули пароль?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Будь ласка, повторіть спробу за хвилину</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Скинути пароль</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Забули пароль?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Перевірку пройдено</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроби</numerusform><numerusform>Перевірку не пройдено, лишилося %n спроб</numerusform><numerusform>Перевірку не пройдено, лишилася %n спроба</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Перевірку не пройдено. Лишилася одна спроба.</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Помилковий пін-код</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Потрібен UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Введіть ваш пін-код</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Будь ласка, повторіть спробу за хвилину</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилини</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилин</numerusform><numerusform>Будь ласка, повторіть спробу за %n хвилину</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Обліковий запис</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Строк дії вашого пароля буде вичерпано за %n день. Будь ласка, вчасно змініть його</numerusform><numerusform>Строк дії вашого пароля буде вичерпано за %n дні. Будь ласка, вчасно змініть його</numerusform><numerusform>Строк дії вашого пароля буде вичерпано за %n днів. Будь ласка, вчасно змініть його</numerusform><numerusform>Строк дії вашого пароля буде вичерпано за %n день. Будь ласка, вчасно змініть його</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Строк дії пароля вичерпано. Будь ласка, змініть</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Блокування екрана</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Не вдалося заблокувати екран</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Не вдалося вчасно пройти розпізнавання за відбитком. Будь ласка, введіть ваш пароль вручну.</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Не вдалося порівняти відбиток</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Вищевказані користувачі все ще знаходяться в системі, і їх дані будуть втрачені внаслідок вимкнення.</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Вищевказані користувачі все ще знаходяться в системі, і їх дані будуть втрачені у випадку перезавантаження. Ви впевнені, що хочете перезавантажитись?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Приспати</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Заблокувати</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Змінити користувача</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Перемкнути систему</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Запустити системний монітор</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Програми не дозволяють вимкнути комп&apos;ютер, а примусове вимкнення може призвести до втрати даних.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Щоб завершити роботу програми, натисніть кнопку «Скасувати» і закрийте вікно програми.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Програми не дозволяють перезавантажити комп&apos;ютер, а примусове перезавантаження може призвести до втрати даних.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Програми не дозволяють призупинити роботу комп&apos;ютера, а примушування призупинення може призвести до втрати даних.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Програми запобігають сплячому стану комп’ютера, а примушування до сплячого режиму може призвести до втрати даних.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Програми перешкоджають виходу з комп&apos;ютера, а примусовий вихід може призвести до втрати даних.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Приспати</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Ви впевнені, що хочете вимкнути компʼютер?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Ви впевнені, що хочете перезавантажити комп&apos;ютер?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Ви впевнені, що хочете вийти?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Вимкнути</translation>
    </message>
</context>
</TS>